# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import vantage
from vantage.api.costs_api import CostsApi  # noqa: E501
from vantage.rest import ApiException


class TestCostsApi(unittest.TestCase):
    """CostsApi unit test stubs"""

    def setUp(self):
        self.api = vantage.api.costs_api.CostsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_costs(self):
        """Test case for get_costs

        """
        pass

    def test_get_report(self):
        """Test case for get_report

        """
        pass

    def test_get_reports(self):
        """Test case for get_reports

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vantage.api_client import ApiClient


class CostsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_costs(self, report_id, **kwargs):  # noqa: E501
        """get_costs  # noqa: E501

        Return available Costs for the specified Cost Report and optional time period. If no time period is specified it will return all available costs for the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_costs(report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_id: (required)
        :param str start_date: Query costs by the first date you would like to filter from. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T19:20:48+00:00.
        :param str end_date: Query costs by the last date you would like to filter to. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T19:20:48+00:00.
        :param int page: The page of results to return.
        :param int limit: The amount of results to return. The maximum is 1000
        :return: Costs
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_costs_with_http_info(report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_costs_with_http_info(report_id, **kwargs)  # noqa: E501
            return data

    def get_costs_with_http_info(self, report_id, **kwargs):  # noqa: E501
        """get_costs  # noqa: E501

        Return available Costs for the specified Cost Report and optional time period. If no time period is specified it will return all available costs for the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_costs_with_http_info(report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_id: (required)
        :param str start_date: Query costs by the first date you would like to filter from. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T19:20:48+00:00.
        :param str end_date: Query costs by the last date you would like to filter to. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T19:20:48+00:00.
        :param int page: The page of results to return.
        :param int limit: The amount of results to return. The maximum is 1000
        :return: Costs
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_id', 'start_date', 'end_date', 'page', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_costs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'report_id' is set
        if self.api_client.client_side_validation and ('report_id' not in params or
                                                       params['report_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `report_id` when calling `get_costs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']  # noqa: E501

        query_params = []
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v1/reports/{report_id}/costs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Costs',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_report(self, report_id, **kwargs):  # noqa: E501
        """get_report  # noqa: E501

        Return a Cost Report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report(report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_id: (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_with_http_info(report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_with_http_info(report_id, **kwargs)  # noqa: E501
            return data

    def get_report_with_http_info(self, report_id, **kwargs):  # noqa: E501
        """get_report  # noqa: E501

        Return a Cost Report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_with_http_info(report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_id: (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'report_id' is set
        if self.api_client.client_side_validation and ('report_id' not in params or
                                                       params['report_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `report_id` when calling `get_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v1/reports/{report_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Report',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_reports(self, **kwargs):  # noqa: E501
        """get_reports  # noqa: E501

        Return all Cost Reports.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_reports(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page of results to return.
        :param int limit: The amount of results to return. The maximum is 1000
        :return: Reports
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_reports_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_reports_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_reports_with_http_info(self, **kwargs):  # noqa: E501
        """get_reports  # noqa: E501

        Return all Cost Reports.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_reports_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page of results to return.
        :param int limit: The amount of results to return. The maximum is 1000
        :return: Reports
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_reports" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v1/reports', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Reports',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import vantage
from vantage.models.products import Products  # noqa: E501
from vantage.rest import ApiException


class TestProducts(unittest.TestCase):
    """Products unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProducts(self):
        """Test Products"""
        # FIXME: construct object with mandatory attributes with example values
        # model = vantage.models.products.Products()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vantage.configuration import Configuration


class Price(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'unit': 'str',
        'region': 'str',
        'rate_type': 'str',
        'currency': 'str',
        'amount': 'float',
        'details': 'object'
    }

    attribute_map = {
        'id': 'id',
        'unit': 'unit',
        'region': 'region',
        'rate_type': 'rate_type',
        'currency': 'currency',
        'amount': 'amount',
        'details': 'details'
    }

    def __init__(self, id=None, unit=None, region=None, rate_type=None, currency=None, amount=None, details=None, _configuration=None):  # noqa: E501
        """Price - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._unit = None
        self._region = None
        self._rate_type = None
        self._currency = None
        self._amount = None
        self._details = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if unit is not None:
            self.unit = unit
        if region is not None:
            self.region = region
        if rate_type is not None:
            self.rate_type = rate_type
        if currency is not None:
            self.currency = currency
        if amount is not None:
            self.amount = amount
        if details is not None:
            self.details = details

    @property
    def id(self):
        """Gets the id of this Price.  # noqa: E501


        :return: The id of this Price.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Price.


        :param id: The id of this Price.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def unit(self):
        """Gets the unit of this Price.  # noqa: E501

        The unit in which the amount is billed.  # noqa: E501

        :return: The unit of this Price.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Price.

        The unit in which the amount is billed.  # noqa: E501

        :param unit: The unit of this Price.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def region(self):
        """Gets the region of this Price.  # noqa: E501

        The region the price is specific to.  # noqa: E501

        :return: The region of this Price.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this Price.

        The region the price is specific to.  # noqa: E501

        :param region: The region of this Price.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def rate_type(self):
        """Gets the rate_type of this Price.  # noqa: E501

        The part of the product the price applies to. (compute, transfer, etc..)  # noqa: E501

        :return: The rate_type of this Price.  # noqa: E501
        :rtype: str
        """
        return self._rate_type

    @rate_type.setter
    def rate_type(self, rate_type):
        """Sets the rate_type of this Price.

        The part of the product the price applies to. (compute, transfer, etc..)  # noqa: E501

        :param rate_type: The rate_type of this Price.  # noqa: E501
        :type: str
        """

        self._rate_type = rate_type

    @property
    def currency(self):
        """Gets the currency of this Price.  # noqa: E501

        The currency of the amount.  # noqa: E501

        :return: The currency of this Price.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Price.

        The currency of the amount.  # noqa: E501

        :param currency: The currency of this Price.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def amount(self):
        """Gets the amount of this Price.  # noqa: E501

        The amount of money this specific product price costs.  # noqa: E501

        :return: The amount of this Price.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Price.

        The amount of money this specific product price costs.  # noqa: E501

        :param amount: The amount of this Price.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def details(self):
        """Gets the details of this Price.  # noqa: E501

        Service specific metadata.  # noqa: E501

        :return: The details of this Price.  # noqa: E501
        :rtype: object
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Price.

        Service specific metadata.  # noqa: E501

        :param details: The details of this Price.  # noqa: E501
        :type: object
        """

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Price, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Price):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Price):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vantage.configuration import Configuration


class Report(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'earliest_cost_date': 'str',
        'latest_cost_date': 'str',
        'created_at': 'str',
        'workspace': 'str'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'earliest_cost_date': 'earliest_cost_date',
        'latest_cost_date': 'latest_cost_date',
        'created_at': 'created_at',
        'workspace': 'workspace'
    }

    def __init__(self, id=None, title=None, earliest_cost_date=None, latest_cost_date=None, created_at=None, workspace=None, _configuration=None):  # noqa: E501
        """Report - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._title = None
        self._earliest_cost_date = None
        self._latest_cost_date = None
        self._created_at = None
        self._workspace = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if earliest_cost_date is not None:
            self.earliest_cost_date = earliest_cost_date
        if latest_cost_date is not None:
            self.latest_cost_date = latest_cost_date
        if created_at is not None:
            self.created_at = created_at
        if workspace is not None:
            self.workspace = workspace

    @property
    def id(self):
        """Gets the id of this Report.  # noqa: E501


        :return: The id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Report.


        :param id: The id of this Report.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this Report.  # noqa: E501

        The title of the cost report.  # noqa: E501

        :return: The title of this Report.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Report.

        The title of the cost report.  # noqa: E501

        :param title: The title of this Report.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def earliest_cost_date(self):
        """Gets the earliest_cost_date of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-01-01 or 2021-01-01T00:00:00Z.  # noqa: E501

        :return: The earliest_cost_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._earliest_cost_date

    @earliest_cost_date.setter
    def earliest_cost_date(self, earliest_cost_date):
        """Sets the earliest_cost_date of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-01-01 or 2021-01-01T00:00:00Z.  # noqa: E501

        :param earliest_cost_date: The earliest_cost_date of this Report.  # noqa: E501
        :type: str
        """

        self._earliest_cost_date = earliest_cost_date

    @property
    def latest_cost_date(self):
        """Gets the latest_cost_date of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-31 or 2021-07-31T00:00:00Z.  # noqa: E501

        :return: The latest_cost_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._latest_cost_date

    @latest_cost_date.setter
    def latest_cost_date(self, latest_cost_date):
        """Sets the latest_cost_date of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-31 or 2021-07-31T00:00:00Z.  # noqa: E501

        :param latest_cost_date: The latest_cost_date of this Report.  # noqa: E501
        :type: str
        """

        self._latest_cost_date = latest_cost_date

    @property
    def created_at(self):
        """Gets the created_at of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T00:00:00Z.  # noqa: E501

        :return: The created_at of this Report.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T00:00:00Z.  # noqa: E501

        :param created_at: The created_at of this Report.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def workspace(self):
        """Gets the workspace of this Report.  # noqa: E501

        The name of the workspace the report is a part of.  # noqa: E501

        :return: The workspace of this Report.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this Report.

        The name of the workspace the report is a part of.  # noqa: E501

        :param workspace: The workspace of this Report.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Report, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Report):
            return True

        return self.to_dict() != other.to_dict()
